<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://bigblue.co
 * @since             1.0.0
 * @package           Bigblue
 *
 * @wordpress-plugin
 * Plugin Name:       Bigblue
 * Plugin URI:        https://bigblue.co
 * Description:       Connect your WooCommerce store to Bigblue logistics.
 * Version:           1.1.1
 * Author:            Bigblue Integrations
 * Author URI:        https://bigblue.co
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       bigblue
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Current plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'BIGBLUE_VERSION', '1.1.1' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-bigblue-activator.php
 */
function activate_bigblue() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-bigblue-activator.php';
	Bigblue_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-bigblue-deactivator.php
 */
function deactivate_bigblue() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-bigblue-deactivator.php';
	Bigblue_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_bigblue' );
register_deactivation_hook( __FILE__, 'deactivate_bigblue' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-bigblue.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_bigblue() {

	$plugin = new Bigblue();
	$plugin->run();

}
run_bigblue();
