<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://bigblue.co
 * @since      1.0.0
 *
 * @package    Bigblue
 * @subpackage Bigblue/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Bigblue
 * @subpackage Bigblue/public
 * @author     Bigblue Integrations <tech@bigblue.io>
 */
class Bigblue_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'store/class-customer-store.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'store/class-bigblue-config-store.php';

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Bigblue_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Bigblue_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/bigblue-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Bigblue_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Bigblue_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/bigblue-public.js', array( 'jquery' ), $this->version, false );

	}

	public function enqueue_pickup_points() {
		$customer = Customer_Store::get_customer();
		$cart = WC()->cart;
		$session = WC()->session;
		$sat = Bigblue_Config_Store::get_storefront_access_token();

		wp_enqueue_script( $this->plugin_name, '//cdn.bigblue.co/modules/woo/1.0.0/pickup.js', array('jquery'), false, true );
		wp_localize_script( $this->plugin_name, 'bigblueX5Ef', array(
			'sat' => $sat,
			'checkoutId' => $this->get_or_create_session_id(),
			'locale' => substr( get_locale(), 0, 2 ),
			'version' => $this->version,
		));
	}

	public function enqueue_fast_tag_script_on_product_page() {
		// Uncomment to test locally the fast tag script.
		// wp_enqueue_script( $this->plugin_name, 'http://localhost:5678/script/woocommerce/main.js', array('jquery'), false, true );
		
		wp_enqueue_script( $this->plugin_name, 'https://bigblueprod-fast-tags.web.app/woocommerce/main.js', array('jquery'), false, true );
		
		$env = array(
			'accessToken' => Bigblue_Config_Store::get_storefront_access_token(),
			'sessionId' => $this->get_or_create_session_id(),
			'locale' => str_replace("_","-",get_locale())
		);

		$product = wc_get_product();
		if ($product) {
			$variations = array();
			if ($product->get_children()) {
				foreach ($product->get_children() as $productChild) {
					$variation = wc_get_product($productChild);
					array_push($variations, array(
						'productId' => $product->get_id(),
						'variationId' => $variation->get_variation_id(),
						'variationPrice' => $variation->get_price(),
					));
				}
			}

			$env['productId'] = $product->get_id();
			$env['productPrice'] = $product->get_price();
			$env['variations'] = $variations;
		}

		$cart = WC()->cart;
		if ($cart) {
			$cartContents = $cart->get_cart_contents();
			$cartItems = array();
			if ($cartContents){
				foreach($cartContents as $item => $values) { 
					array_push($cartItems, array(
						'productId' => $values['product_id'],
						'variationId' => $values['variation_id'],
						'quantity' => $values['quantity'],
					));
				} 
			}

			$env['cartAmount'] =  $cart->total;
			$env['cartCurrency'] = get_woocommerce_currency();
			$env['cartItems'] = $cartItems;
		}

		wp_localize_script( $this->plugin_name, 'wooBBFTEnv', $env);
	}

	public function inject_product_fast_tag() {
		// data-source="wcplugin" states that <bigblue/> is injected by wooCommerce plugin.
		echo '<bigblue data-source="wcplugin"></bigblue>';
	}

	public function inject_hidden_inputs() {

		echo '<div id="user_link_hidden_checkout_field">
			   <input type="hidden" class="input-hidden" name="bb_checkout_id" id="bb_checkout_id" value="' . $this->get_or_create_session_id() . '"/>
			   <input type="hidden" class="input-hidden" name="bb_shipping_method_id" id="bb_shipping_method_id" value=""/>
		</div>';
	}

	public function inject_preact_root_div() {
		echo '<div class="bigblue-pickup"></div>';
	}

	public function add_hidden_inputs_to_order_meta( $order_id ) {
		if ( ! empty( $_POST['bb_checkout_id'] ) ) {
			update_post_meta( $order_id, '_bb_checkout_id', sanitize_text_field( $_POST['bb_checkout_id'] ) );

			// reset checkout id on order creation
			WC()->session->set('bb_checkout_id', null);
		}

		if ( ! empty( $_POST['bb_shipping_method_id'] ) ) {
			update_post_meta( $order_id, '_bb_shipping_method_id', sanitize_text_field( $_POST['bb_shipping_method_id'] ) );
		}
	}

	// Return an empty string if the session isn't available yet.
	protected function get_or_create_session_id() {
		$session = WC()->session;
		// Depending on the hook in which code is run, requiring the session ID from this code may fail because the session isn't instantiated yet.
		// To prevent a crash of the plugin in this case, the session is first checked before getting "bb_checkout_id".
		// Example: In the hook "woocommerce_init", $session is empty.
		if ($session) {
			if ( $session->get('bb_checkout_id') == null ) {
				$session->set('bb_checkout_id', $this->random_string(16));
			}

			return $session->get('bb_checkout_id');
		}
		return "";
	}

    protected function random_string($length = 8 ) {
		$pool = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
		
		$crypto_rand_secure = function ( $min, $max ) {
			$range = $max - $min;
			if ( $range < 0 ) return $min; // not so random...
			$log    = log( $range, 2 );
			$bytes  = (int) ( $log / 8 ) + 1; // length in bytes
			$bits   = (int) $log + 1; // length in bits
			$filter = (int) ( 1 << $bits ) - 1; // set all lower bits to 1
			do {
				$rnd = hexdec( bin2hex( openssl_random_pseudo_bytes( $bytes ) ) );
				$rnd = $rnd & $filter; // discard irrelevant bits
			} while ( $rnd >= $range );
			return $min + $rnd;
		};
		
		$token = "";
		$max   = strlen( $pool );
		for ( $i = 0; $i < $length; $i++ ) {
			$token .= $pool[$crypto_rand_secure( 0, $max )];
		}
		return $token;
	}
}
