<?php

/**
* The plugin config data access layer
*
* @link       https://bigblue.co
* @since      1.0.0
*
* @package    Bigblue
* @subpackage Bigblue/store
*/

/**
 * Bigblue plugin config store class.
 *
 * Helper to manage consistency between woocommerce versions customer getters and setters.
 *
 * @class       Bigblue_Config_Store
 * @package     Bigblue
 * @subpackage  Bigblue/store
 * @author      Bigblue Integrations <tech@bigblue.io>
 */
class Bigblue_Config_Store
{

    const CONFIG_PREFIX = 'BIGBLUE_';
    const KEY_STOREFRONT_ACCESS_TOKEN = 'SAT';
    const KEY_STOREFRONT_ACCESS_TOKEN_EXPIRY = 'SAT_EXPIRY';

    /**
     * Fetch config entry.
     *
     * @param string $key entry name
     * @param mixed $default entry default value
     *
     * @return string entry value
     */
    protected static function get( $key, $shopGroupId = null, $shopId = null, $default = null ) {
        $value = get_option( self::CONFIG_PREFIX . $key, $default );

        return null !== $value && false !== $value && '' !== $value ? $value : null;
    }

    /**
     * Set config entry.
     *
     * @param string $key entry name
     * @param string $value entry value
     *
     * @void
     */
    protected static function set( $key, $value ) {
        update_option( self::CONFIG_PREFIX . $key, $value);
    }

    /**
     * Delete option. Do NOT delete value in configuration cache.
     *
     * @param string $key option name
     *
     * @void
     */
    protected static function delete( $key ) {
        delete_option( self::CONFIG_PREFIX . $key );
    }

    /**
     * Get Storefront Access Token
     *
     * @return string SA token
     */
    public static function get_storefront_access_token() {

        $sat = self::get( self::KEY_STOREFRONT_ACCESS_TOKEN, '' );
        if ($sat === '') {
            return null;
        }

        $exp = intval( self::get( self::KEY_STOREFRONT_ACCESS_TOKEN_EXPIRY ) );
        if ( $exp < time() ) {
            return null;
        }

        return $sat;
    }

    /**
     * Set Storefront Access Token
     * @param string $token
     * @param int $expiry
     * 
     * @void
     */
    public static function set_storefront_access_token( $token, $expiry ) {
        self::set( self::KEY_STOREFRONT_ACCESS_TOKEN, $token );
        self::set( self::KEY_STOREFRONT_ACCESS_TOKEN_EXPIRY, $expiry );
    }

    /**
     * Delete configuration.
     *
     * @void
     */
    public static function delete_configuration() {
        self::delete( self::KEY_STOREFRONT_ACCESS_TOKEN );
    }
}